==> eyantra-autoeval-0.1.10.tar.gz: eyantra-autoeval-0.1.10/eyantra_autoeval/console.py <==
#!/usr/bin/env python3

# standard imports
import importlib
import json
import logging
import time

# third-party imprts
import click
from rich import print
from rich.logging import RichHandler

FORMAT = "%(message)s"


@click.group()
def cli():
    pass


@click.command()
@click.option("--year", required=True, help="Year.")
@click.option("--theme", required=True, help="Theme Initials.")
@click.option("--task", required=True, help="Task Number.")
@click.option("--verbose", is_flag=True, help="Run in verbose mode.")
def evaluate(year, theme, task, verbose):
    """Dry run evaluation for a task."""
    print(
        f"Running evaluation scripts for [bold blue]{year}[/bold blue] "
        f"theme [bold blue]{theme}[/bold blue] for "
        f"task [bold blue]{task}[/bold blue]"
    )
    logging.basicConfig(
        level="DEBUG" if verbose else "INFO",
        format=FORMAT,
        datefmt="[%X]",
        handlers=[RichHandler()],
    )
    log = logging.getLogger("rich")

    evaluator = importlib.import_module(
        f"eyantra_autoeval.year.y{year}.{theme}.task{task}.evaluator"
    )

    start_time = time.time()
    try:
        log.debug("Calling appropriate evaluator")
        result = evaluator.evaluate()
    except Exception as err:
        log.error(err)
    end_time = time.time()

    result["meta"] = {}
    result["meta"]["evaluation_time"] = end_time - start_time

    log.debug(result)
    with open(f"result-{year}-{theme}-{task}.json", "w", encoding="utf-8") as file:
        json.dump(result, file, ensure_ascii=False, indent=4)


cli.add_command(evaluate)

==> eyantra-autoeval-0.1.14.tar.gz: eyantra-autoeval-0.1.14/eyantra_autoeval/console.py <==
#!/usr/bin/env python3

# standard imports
import importlib
import json
import logging
import time
from datetime import datetime

# third-party imprts
import click
from eyantra_autoeval.utils.common import keycloak_login
from rich import print
from rich.logging import RichHandler

FORMAT = "%(message)s"


@click.group()
def cli():
    pass


@click.command()
@click.option("--year", required=True, help="Year.")
@click.option("--theme", required=True, help="Theme Initials.")
@click.option("--task", required=True, help="Task Number.")
@click.option("--verbose", is_flag=True, help="Run in verbose mode.")
def evaluate(year, theme, task, verbose):
    """Dry run evaluation for a task."""
    print(
        f"Running evaluation scripts for [bold blue]{year}[/bold blue] "
        f"theme [bold blue]{theme}[/bold blue] for "
        f"task [bold blue]{task}[/bold blue]"
    )
    logging.basicConfig(
        level="DEBUG" if verbose else "INFO",
        format=FORMAT,
        datefmt="[%X]",
        handlers=[RichHandler()],
    )
    log = logging.getLogger("rich")

    evaluator = importlib.import_module(
        f"eyantra_autoeval.year.y{year}.{theme}.task{task}.evaluator"
    )

    start_time = time.time()
    try:
        log.debug("Calling appropriate evaluator")
        result = evaluator.evaluate()
    except Exception as err:
        log.error(err)
    end_time = time.time()

    result["meta"] = {}
    result["meta"]["evaluation_time"] = end_time - start_time

    log.debug(result)
    with open(
        f"result-{year}-{theme}-{task}-{datetime.now().strftime('%Y%m%d')}.json",
        "w",
        encoding="utf-8",
    ) as file:
        json.dump(result, file, ensure_ascii=False, indent=4)


@click.command()
def upload():
    """Upload an evaluation."""
    keycloak_login()


cli.add_command(evaluate)
cli.add_command(upload)
